import { Command } from 'ckeditor5/src/core';

class InsertAccordionCommand extends Command {
  constructor(editor) {
    super(editor);

    const { options } = editor.config.get('uswdsAccordionConfig');

    this.defaultBordered = options.bordered;
    this.defaultCollapsed = options.collapsed;
    this.defaultMultiselect = options.multiselect;
    this.defaultClass = 'usa-accordion';

    if (this.defaultBordered) {
      this.defaultClass += ' usa-accordion--bordered';
    }
  }

  execute() {
    const { model } = this.editor;

    model.change(writer => {
      // Create the accordion element without attributes.
      const accordion = writer.createElement('accordion');

      // Create and append the child elements.
      const accordionTitle = writer.createElement('accordionTitle');
      const accordionContent = writer.createElement('accordionContent');

      writer.append(accordionTitle, accordion);
      writer.append(accordionContent, accordion);
      writer.appendElement('paragraph', accordionContent);

      // Insert the accordion into the model.
      model.insertContent(accordion);

      // Set the necessary attributes after insertion.
      writer.setAttribute('class', this.defaultClass, accordion);

      if (this.defaultMultiselect) {
        writer.setAttribute(
          'data-allow-multiple',
          'true',
          accordion
        );
      }

      writer.setAttribute(
        'aria-expanded',
        this.defaultCollapsed ? 'false' : 'true',
        accordionTitle
      );

      // Set the selection on the newly inserted accordion.
      writer.setSelection(accordion, 'on');
    });
  }

  refresh() {
    const { model } = this.editor;
    const { selection } = model.document;

    const allowedIn = model.schema.findAllowedParent(
      selection.getFirstPosition(),
      'accordion'
    );

    this.isEnabled = allowedIn !== null;
  }
}

export default InsertAccordionCommand;