/**
 * @file defines OpenAccordionPropertiesCommand.
 */

import { Command } from 'ckeditor5/src/core';

/**
 * The OpenAccordionPropertiesCommand class provides a command
 * for opening the accordion properties dialog.
 */
class OpenAccordionPropertiesCommand extends Command {
  constructor(editor) {
    super(editor);
  }

  /**
   * Executes the command.
   * @param {Object} options - The options for the command.
   */
  execute(options) {
    const editor = this.editor;
    const selection = editor.model.document.selection;
    const accordion = selection.getFirstPosition().findAncestor('accordion');
    const properties = editor.plugins.get('AccordionPropertiesDialog');

    if (!accordion) {
      console.error('No accordion element selected.');
      return;
    }

    if (!properties || !properties.dialog) {
      console.error('AccordionPropertiesDialog plugin or dialog instance not found');
      return;
    }

    properties.open(accordion);
  }

  /**
   * Refreshes the command state.
   */
  refresh() {
    this.isEnabled = true;
  }
}

export default OpenAccordionPropertiesCommand;