<?php

declare(strict_types=1);

namespace Drupal\uswds_ckeditor_integration\Plugin\CKEditor5Plugin;

use Drupal\Core\Form\FormStateInterface;
use Drupal\ckeditor5\Plugin\CKEditor5PluginConfigurableInterface;
use Drupal\ckeditor5\Plugin\CKEditor5PluginConfigurableTrait;
use Drupal\ckeditor5\Plugin\CKEditor5PluginDefault;
use Drupal\editor\EditorInterface;

/**
 * CKEditor 5 USWDS class overrides.
 *
 * @internal
 *   Plugin classes are internal.
 */
class UswdsAccordion extends CKEditor5PluginDefault implements CKEditor5PluginConfigurableInterface {

  use CKEditor5PluginConfigurableTrait;

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
      'bordered' => FALSE,
      'multiselect' => FALSE,
      'collapsed' => FALSE,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form['bordered'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Default with border.'),
      '#default_value' => $this->configuration['bordered'],
    ];
    $form['multiselect'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Default with multiselect.'),
      '#default_value' => $this->configuration['multiselect'],
    ];
    $form['collapsed'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Default collapsed.'),
      '#default_value' => $this->configuration['collapsed'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state): void {
    $form_value = $form_state->getValue('bordered');
    $form_state->setValue('bordered', (bool) $form_value);
    $form_value = $form_state->getValue('multiselect');
    $form_state->setValue('multiselect', (bool) $form_value);
    $form_value = $form_state->getValue('collapsed');
    $form_state->setValue('collapsed', (bool) $form_value);
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state): void {
    $this->configuration['bordered'] = $form_state->getValue('bordered');
    $this->configuration['multiselect'] = $form_state->getValue('multiselect');
    $this->configuration['collapsed'] = $form_state->getValue('collapsed');
  }

  /**
   * {@inheritdoc}
   */
  public function getDynamicPluginConfig(array $static_plugin_config, EditorInterface $editor): array {
    $static_plugin_config['uswdsAccordionConfig']['options'] = $this->getConfiguration();

    return $static_plugin_config;
  }

}
